package com.ruoyi.ss.vipLevel.service.impl;

import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.ss.store.service.StoreService;
import com.ruoyi.ss.vipLevel.domain.VipLevelVO;
import com.ruoyi.ss.vipLevel.service.VipLevelAssembler;
import com.ruoyi.ss.vipLevelSku.domain.VipLevelSkuQuery;
import com.ruoyi.ss.vipLevelSku.domain.VipLevelSkuVO;
import com.ruoyi.ss.vipLevelSku.domain.enums.VipLevelSkuStatus;
import com.ruoyi.ss.vipLevelSku.service.VipLevelSkuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class VipLevelAssemblerImpl implements VipLevelAssembler {

    @Autowired
    private StoreService storeService;

    @Autowired
    private VipLevelSkuService vipLevelSkuService;


    @Override
    public void assembleSkuList(List<VipLevelVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<Long> levelIds = list.stream().map(VipLevelVO::getId).collect(Collectors.toList());

        Map<Long, List<VipLevelSkuVO>> group = vipLevelSkuService.selectByLevelIds(levelIds)
            .stream().collect(Collectors.groupingBy(VipLevelSkuVO::getLevelId));

        for (VipLevelVO vipLevel : list) {
            List<VipLevelSkuVO> vipLevelSkuList = group.get(vipLevel.getId());
            if (vipLevelSkuList == null) {
                vipLevelSkuList = Collections.emptyList();
            }
            vipLevel.setSkuList(vipLevelSkuList);
        }
    }

    @Override
    public void assembleSaleSkuList(List<VipLevelVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<Long> levelIds = list.stream().map(VipLevelVO::getId).collect(Collectors.toList());

        VipLevelSkuQuery query = new VipLevelSkuQuery();
        query.setLevelIds(levelIds);
        query.setStatus(VipLevelSkuStatus.ON_SALE.getStatus());
        Map<Long, List<VipLevelSkuVO>> group = vipLevelSkuService.selectVipLevelSkuList(query)
                .stream().collect(Collectors.groupingBy(VipLevelSkuVO::getLevelId));

        for (VipLevelVO vipLevel : list) {
            List<VipLevelSkuVO> vipLevelSkuList = group.get(vipLevel.getId());
            if (vipLevelSkuList == null) {
                vipLevelSkuList = Collections.emptyList();
            }
            vipLevel.setSkuList(vipLevelSkuList);
        }

    }
}
